# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.roles import roles_pb2 as scalekit_dot_v1_dot_roles_dot_roles__pb2


class RolesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateRole = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/CreateRole',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateRoleRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateRoleResponse.FromString,
                )
        self.UpdateRole = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/UpdateRole',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateRoleRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateRoleResponse.FromString,
                )
        self.GetRole = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/GetRole',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleResponse.FromString,
                )
        self.ListRoles = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/ListRoles',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolesResponse.FromString,
                )
        self.DeleteRole = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/DeleteRole',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteRoleRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateOrganizationRole = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/CreateOrganizationRole',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateOrganizationRoleRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateOrganizationRoleResponse.FromString,
                )
        self.UpdateOrganizationRole = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/UpdateOrganizationRole',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateOrganizationRoleRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateOrganizationRoleResponse.FromString,
                )
        self.GetOrganizationRole = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/GetOrganizationRole',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleResponse.FromString,
                )
        self.ListOrganizationRoles = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/ListOrganizationRoles',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListOrganizationRolesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListOrganizationRolesResponse.FromString,
                )
        self.DeleteOrganizationRole = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/DeleteOrganizationRole',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteOrganizationRoleRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetRoleUsersCount = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/GetRoleUsersCount',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleUsersCountRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleUsersCountResponse.FromString,
                )
        self.GetOrganizationRoleUsersCount = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/GetOrganizationRoleUsersCount',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleUsersCountRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleUsersCountResponse.FromString,
                )
        self.UpdateDefaultRoles = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/UpdateDefaultRoles',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultRolesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultRolesResponse.FromString,
                )
        self.UpdateDefaultOrganizationRoles = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/UpdateDefaultOrganizationRoles',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultOrganizationRolesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultOrganizationRolesResponse.FromString,
                )
        self.ListDependentRoles = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/ListDependentRoles',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListDependentRolesRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListDependentRolesResponse.FromString,
                )
        self.DeleteRoleBase = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/DeleteRoleBase',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteRoleBaseRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteOrganizationRoleBase = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/DeleteOrganizationRoleBase',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteOrganizationRoleBaseRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreatePermission = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/CreatePermission',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreatePermissionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreatePermissionResponse.FromString,
                )
        self.GetPermission = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/GetPermission',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetPermissionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetPermissionResponse.FromString,
                )
        self.UpdatePermission = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/UpdatePermission',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdatePermissionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdatePermissionResponse.FromString,
                )
        self.ListPermissions = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/ListPermissions',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListPermissionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListPermissionsResponse.FromString,
                )
        self.DeletePermission = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/DeletePermission',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.DeletePermissionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListRolePermissions = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/ListRolePermissions',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolePermissionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolePermissionsResponse.FromString,
                )
        self.AddPermissionsToRole = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/AddPermissionsToRole',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.AddPermissionsToRoleRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.AddPermissionsToRoleResponse.FromString,
                )
        self.RemovePermissionFromRole = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/RemovePermissionFromRole',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.RemovePermissionFromRoleRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListEffectiveRolePermissions = channel.unary_unary(
                '/scalekit.v1.roles.RolesService/ListEffectiveRolePermissions',
                request_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListEffectiveRolePermissionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListEffectiveRolePermissionsResponse.FromString,
                )


class RolesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganizationRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRoleUsersCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationRoleUsersCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDefaultRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDefaultOrganizationRoles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDependentRoles(self, request, context):
        """Role Hierarchy Management RPCs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRoleBase(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationRoleBase(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePermission(self, request, context):
        """Permission Management RPCs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPermissions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRolePermissions(self, request, context):
        """rpc BatchCreatePermissions(BatchCreatePermissionsRequest) returns (BatchCreatePermissionsResponse) {
        option (scalekit.v1.options.auth_option) = {authentication_type: WORKSPACE_SESSION};

        option (google.api.http) = {
        post: "/api/v1/permissions/batch"
        body: "*"
        };

        option (grpc.gateway.protoc_gen_openapiv2.options.openapiv2_operation) = {
        tags: "Permissions"
        summary: "Batch Create/Update Permissions"
        description: "Create or update multiple permissions in a single operation"

        responses: {
        key: "200"
        value: {
        description: "Batch operation completed successfully"
        schema: {
        json_schema: {ref: ".scalekit.v1.roles.BatchCreatePermissionsResponse"}
        }
        }
        }
        };
        }

        Role-Permission Management RPCs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPermissionsToRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePermissionFromRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEffectiveRolePermissions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RolesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateRole': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRole,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateRoleRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateRoleResponse.SerializeToString,
            ),
            'UpdateRole': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRole,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateRoleRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateRoleResponse.SerializeToString,
            ),
            'GetRole': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRole,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleResponse.SerializeToString,
            ),
            'ListRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRoles,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolesResponse.SerializeToString,
            ),
            'DeleteRole': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRole,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteRoleRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateOrganizationRole': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganizationRole,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateOrganizationRoleRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateOrganizationRoleResponse.SerializeToString,
            ),
            'UpdateOrganizationRole': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationRole,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateOrganizationRoleRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateOrganizationRoleResponse.SerializeToString,
            ),
            'GetOrganizationRole': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationRole,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleResponse.SerializeToString,
            ),
            'ListOrganizationRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationRoles,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListOrganizationRolesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListOrganizationRolesResponse.SerializeToString,
            ),
            'DeleteOrganizationRole': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationRole,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteOrganizationRoleRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetRoleUsersCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRoleUsersCount,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleUsersCountRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleUsersCountResponse.SerializeToString,
            ),
            'GetOrganizationRoleUsersCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationRoleUsersCount,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleUsersCountRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleUsersCountResponse.SerializeToString,
            ),
            'UpdateDefaultRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDefaultRoles,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultRolesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultRolesResponse.SerializeToString,
            ),
            'UpdateDefaultOrganizationRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDefaultOrganizationRoles,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultOrganizationRolesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultOrganizationRolesResponse.SerializeToString,
            ),
            'ListDependentRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDependentRoles,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListDependentRolesRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListDependentRolesResponse.SerializeToString,
            ),
            'DeleteRoleBase': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRoleBase,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteRoleBaseRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteOrganizationRoleBase': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationRoleBase,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteOrganizationRoleBaseRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreatePermission': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePermission,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreatePermissionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.CreatePermissionResponse.SerializeToString,
            ),
            'GetPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPermission,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetPermissionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.GetPermissionResponse.SerializeToString,
            ),
            'UpdatePermission': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePermission,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdatePermissionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdatePermissionResponse.SerializeToString,
            ),
            'ListPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPermissions,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListPermissionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListPermissionsResponse.SerializeToString,
            ),
            'DeletePermission': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePermission,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.DeletePermissionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListRolePermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRolePermissions,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolePermissionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolePermissionsResponse.SerializeToString,
            ),
            'AddPermissionsToRole': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPermissionsToRole,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.AddPermissionsToRoleRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.AddPermissionsToRoleResponse.SerializeToString,
            ),
            'RemovePermissionFromRole': grpc.unary_unary_rpc_method_handler(
                    servicer.RemovePermissionFromRole,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.RemovePermissionFromRoleRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListEffectiveRolePermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEffectiveRolePermissions,
                    request_deserializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListEffectiveRolePermissionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_roles_dot_roles__pb2.ListEffectiveRolePermissionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.roles.RolesService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RolesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/CreateRole',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateRoleRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateRoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/UpdateRole',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateRoleRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateRoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/GetRole',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/ListRoles',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolesRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/DeleteRole',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteRoleRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganizationRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/CreateOrganizationRole',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateOrganizationRoleRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.CreateOrganizationRoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/UpdateOrganizationRole',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateOrganizationRoleRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateOrganizationRoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/GetOrganizationRole',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/ListOrganizationRoles',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListOrganizationRolesRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListOrganizationRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/DeleteOrganizationRole',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteOrganizationRoleRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRoleUsersCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/GetRoleUsersCount',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleUsersCountRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.GetRoleUsersCountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationRoleUsersCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/GetOrganizationRoleUsersCount',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleUsersCountRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.GetOrganizationRoleUsersCountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDefaultRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/UpdateDefaultRoles',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultRolesRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDefaultOrganizationRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/UpdateDefaultOrganizationRoles',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultOrganizationRolesRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdateDefaultOrganizationRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDependentRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/ListDependentRoles',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListDependentRolesRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListDependentRolesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRoleBase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/DeleteRoleBase',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteRoleBaseRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationRoleBase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/DeleteOrganizationRoleBase',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.DeleteOrganizationRoleBaseRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/CreatePermission',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.CreatePermissionRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.CreatePermissionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/GetPermission',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.GetPermissionRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.GetPermissionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/UpdatePermission',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdatePermissionRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.UpdatePermissionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/ListPermissions',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListPermissionsRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListPermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/DeletePermission',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.DeletePermissionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRolePermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/ListRolePermissions',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolePermissionsRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListRolePermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddPermissionsToRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/AddPermissionsToRole',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.AddPermissionsToRoleRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.AddPermissionsToRoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemovePermissionFromRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/RemovePermissionFromRole',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.RemovePermissionFromRoleRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEffectiveRolePermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.roles.RolesService/ListEffectiveRolePermissions',
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListEffectiveRolePermissionsRequest.SerializeToString,
            scalekit_dot_v1_dot_roles_dot_roles__pb2.ListEffectiveRolePermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.connections import connections_pb2 as scalekit_dot_v1_dot_connections_dot_connections__pb2


class ConnectionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/CreateEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.FromString,
                )
        self.CreateConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/CreateConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.FromString,
                )
        self.AssignDomainsToConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/AssignDomainsToConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionResponse.FromString,
                )
        self.GetEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/GetEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.FromString,
                )
        self.GetConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/GetConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.FromString,
                )
        self.ListConnections = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/ListConnections',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsResponse.FromString,
                )
        self.ListOrganizationConnections = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/ListOrganizationConnections',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsResponse.FromString,
                )
        self.SearchOrganizationConnections = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/SearchOrganizationConnections',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsResponse.FromString,
                )
        self.UpdateEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/UpdateEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.FromString,
                )
        self.UpdateConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/UpdateConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.FromString,
                )
        self.DeleteEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/DeleteEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/DeleteConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteConnectionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.EnableEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/EnableEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
                )
        self.EnableConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/EnableConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
                )
        self.DisableEnvironmentConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/DisableEnvironmentConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
                )
        self.DisableConnection = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/DisableConnection',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
                )
        self.GetConnectionTestResult = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/GetConnectionTestResult',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultResponse.FromString,
                )
        self.ListAppConnections = channel.unary_unary(
                '/scalekit.v1.connections.ConnectionService/ListAppConnections',
                request_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsResponse.FromString,
                )


class ConnectionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AssignDomainsToConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchOrganizationConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableEnvironmentConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnectionTestResult(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAppConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConnectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateEnvironmentConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.SerializeToString,
            ),
            'CreateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.SerializeToString,
            ),
            'AssignDomainsToConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.AssignDomainsToConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionResponse.SerializeToString,
            ),
            'GetEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetEnvironmentConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.SerializeToString,
            ),
            'GetConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.SerializeToString,
            ),
            'ListConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConnections,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsResponse.SerializeToString,
            ),
            'ListOrganizationConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationConnections,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsResponse.SerializeToString,
            ),
            'SearchOrganizationConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchOrganizationConnections,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsResponse.SerializeToString,
            ),
            'UpdateEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateEnvironmentConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.SerializeToString,
            ),
            'UpdateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.SerializeToString,
            ),
            'DeleteEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteEnvironmentConnectionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteConnectionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'EnableEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.SerializeToString,
            ),
            'EnableConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.SerializeToString,
            ),
            'DisableEnvironmentConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableEnvironmentConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.SerializeToString,
            ),
            'DisableConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableConnection,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.SerializeToString,
            ),
            'GetConnectionTestResult': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnectionTestResult,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultResponse.SerializeToString,
            ),
            'ListAppConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAppConnections,
                    request_deserializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.connections.ConnectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConnectionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/CreateEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateEnvironmentConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/CreateConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.CreateConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AssignDomainsToConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/AssignDomainsToConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.AssignDomainsToConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/GetEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetEnvironmentConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/GetConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/ListConnections',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/ListOrganizationConnections',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListOrganizationConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchOrganizationConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/SearchOrganizationConnections',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.SearchOrganizationConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/UpdateEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateEnvironmentConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/UpdateConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.UpdateConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/DeleteEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteEnvironmentConnectionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/DeleteConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.DeleteConnectionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/EnableEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnableConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/EnableConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableEnvironmentConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/DisableEnvironmentConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleEnvironmentConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/DisableConnection',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ToggleConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConnectionTestResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/GetConnectionTestResult',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.GetConnectionTestResultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAppConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.connections.ConnectionService/ListAppConnections',
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsRequest.SerializeToString,
            scalekit_dot_v1_dot_connections_dot_connections__pb2.ListAppConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Optional, List, Dict

from scalekit.core import CoreClient
from scalekit.v1.organizations.organizations_pb2 import *
from scalekit.v1.organizations.organizations_pb2_grpc import OrganizationServiceStub


class OrganizationClient:
    """Class definition for Organization Client"""

    def __init__(self, core_client: CoreClient):
        """
        Initializer for Organization Client

        :param core_client    : CoreClient Object
        :type                 : ``` obj ```
        :returns
            None
        """
        self.core_client = core_client
        self.organization_service = OrganizationServiceStub(
            self.core_client.grpc_secure_channel
        )

    def list_organizations(
        self, page_size: int, page_token: Optional[str] = None
    ) -> ListOrganizationsResponse:
        """
        Method to list organizations

        :param page_size  : page size for org list fetch
        :type             : ``` int ```
        :param page_token : page token for org list fetch
        :type             : ``` str ```
        :returns:
             list of organizations
        """
        return self.core_client.grpc_exec(
            self.organization_service.ListOrganization.with_call,
            ListOrganizationsRequest(page_size=page_size, page_token=page_token),
        )

    def create_organization(
        self, organization: CreateOrganization
    ) -> CreateOrganizationResponse:
        """
        Method to create organization based on given data

        :param organization  : Create Organization obj with details for org creation
        :type                : ``` obj ```
        :returns:
            Create Organization Response
        """
        return self.core_client.grpc_exec(
            self.organization_service.CreateOrganization.with_call,
            CreateOrganizationRequest(organization=organization),
        )

    def update_organization(
        self, organization_id: str, organization: UpdateOrganization
    ) -> UpdateOrganizationResponse:
        """
        Method to update organization based on given data

        :param organization_id       : Organization id to update
        :type               : ``` str ```
        :param organization : params for update organization operation
        :type               : ``` obj ```
        :returns:
            Update Organization Response
        """
        return self.core_client.grpc_exec(
            self.organization_service.UpdateOrganization.with_call,
            UpdateOrganizationRequest(id=organization_id, organization=organization),
        )

    def update_organization_by_external_id(
        self, external_id: str, organization: UpdateOrganization
    ) -> UpdateOrganizationResponse:
        """
        Method to update organization based on external id

        :param external_id  : External id to update org
        :type               : ``` str ```
        :param organization : params for update organization operation
        :type               : ``` obj ```

        :returns:
            Update Organization Response
        """
        return self.core_client.grpc_exec(
            self.organization_service.UpdateOrganization.with_call,
            UpdateOrganizationRequest(external_id=external_id, organization=organization),
        )

    def get_organization(self, organization_id: str) -> GetOrganizationResponse:
        """
        Method to get organization based on given org id

        :param organization_id  : Organization id
        :type          : ``` str ```
        :returns:
            Get Organization Response
        """
        return self.core_client.grpc_exec(
            self.organization_service.GetOrganization.with_call,
            GetOrganizationRequest(id=organization_id),
        )

    def get_organization_by_external_id(self, external_id: str):
        """
        Method to get organization based on given org id

        :param external_id  : External id to fetch org details
        :type               : ``` str ```
        :returns:
            Get Organization Response
        """
        return self.core_client.grpc_exec(
            self.organization_service.GetOrganization.with_call,
            GetOrganizationRequest(external_id=external_id),
        )

    def delete_organization(self, organization_id: str):
        """
        Method to delete organization based on given org id

        :param organization_id  : Organization id
        :type          : ``` str ```
        :returns:
            None
        """
        return self.core_client.grpc_exec(
            self.organization_service.DeleteOrganization.with_call,
            DeleteOrganizationRequest(id=organization_id),
        )

    def generate_portal_link(self, organization_id: str, features: [Feature] = None) -> GeneratePortalLinkResponse:
        """
        Method to generate customer portal link

        :param organization_id   :  Organization id to fetch portal link for
        :type                    :  ``` str ```
        :param  features         :  Feature list to generate portal link for
        :type                    :  ```dict```
        :return:
        """
        response = self.core_client.grpc_exec(
            self.organization_service.GeneratePortalLink.with_call,
            GeneratePortalLinkRequest(id=organization_id, features=features),
        )
        if not response[0].link:
            raise Exception("Error generating portal link")
        return response[0].link

    def update_organization_settings(self, organization_id: str, settings: List[Dict[str, bool]]):
        """
        Method to update organization settings

        :param organization_id    : Organization id for org update
        :type                     : ``` str ```
        :param settings           : Organization settings
        :type                     : ``` list[dict[str, bool]] ```

        :returns:
            None
        """
        return self.core_client.grpc_exec(
            self.organization_service.UpdateOrganizationSettings.with_call,
            UpdateOrganizationSettingsRequest(
                id=organization_id, settings={'features': settings})
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/migrations/migrations.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from scalekit.v1.commons import commons_pb2 as scalekit_dot_v1_dot_commons_dot_commons__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'scalekit/v1/migrations/migrations.proto\x12\x16scalekit.v1.migrations\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a!scalekit/v1/commons/commons.proto\x1a!scalekit/v1/options/options.proto\"~\n\x18MigrationServiceResponse\x12\x31\n\x14success_environments\x18\x01 \x01(\x05R\x13successEnvironments\x12/\n\x13\x66\x61iled_environments\x18\x02 \x01(\x05R\x12\x66\x61iledEnvironments\"f\n\x14MigrationSAMLRequest\x12\'\n\x0f\x65nvironment_ids\x18\x01 \x03(\x03R\x0e\x65nvironmentIds\x12%\n\nbatch_size\x18\x02 \x01(\x05\x42\x06\xbaH\x03\xc8\x01\x01R\tbatchSize\"\xad\x01\n\x11MigrateFSARequest\x12\'\n\x0f\x65nvironment_ids\x18\x01 \x03(\x03R\x0e\x65nvironmentIds\x12H\n\tdata_type\x18\x02 \x01(\x0e\x32#.scalekit.v1.migrations.FSADataTypeB\x06\xbaH\x03\xc8\x01\x01R\x08\x64\x61taType\x12%\n\nbatch_size\x18\x03 \x01(\x05\x42\x06\xbaH\x03\xc8\x01\x01R\tbatchSize\"z\n\x14MigrationFSAResponse\x12\x31\n\x14success_environments\x18\x01 \x01(\x05R\x13successEnvironments\x12/\n\x13\x66\x61iled_environments\x18\x02 \x01(\x05R\x12\x66\x61iledEnvironments\"{\n\x15MigrationSAMLResponse\x12\x31\n\x14success_environments\x18\x01 \x01(\x05R\x13successEnvironments\x12/\n\x13\x66\x61iled_environments\x18\x02 \x01(\x05R\x12\x66\x61iledEnvironments*\x88\x01\n\x0b\x46SADataType\x12\x1d\n\x19\x46SA_DATA_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x46SA_DATA_TYPE_CONNECTION\x10\x01\x12\x19\n\x15\x46SA_DATA_TYPE_SESSION\x10\x02\x12!\n\x1d\x46SA_DATA_TYPE_USER_MANAGEMENT\x10\x03\x32\xb1\x01\n\x10MigrationService\x12\x9c\x01\n\x0eMigrateFSAData\x12).scalekit.v1.migrations.MigrateFSARequest\x1a,.scalekit.v1.migrations.MigrationFSAResponse\"1\x82\xb5\x18\x02\x18\x01\xfa\xd2\xe4\x93\x02\t\x12\x07PREVIEW\x82\xd3\xe4\x93\x02\x16\"\x14/migrations/fsa-dataB6Z4github.com/scalekit-inc/scalekit/pkg/grpc/migrationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.migrations.migrations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z4github.com/scalekit-inc/scalekit/pkg/grpc/migrations'
  _globals['_MIGRATIONSAMLREQUEST'].fields_by_name['batch_size']._loaded_options = None
  _globals['_MIGRATIONSAMLREQUEST'].fields_by_name['batch_size']._serialized_options = b'\272H\003\310\001\001'
  _globals['_MIGRATEFSAREQUEST'].fields_by_name['data_type']._loaded_options = None
  _globals['_MIGRATEFSAREQUEST'].fields_by_name['data_type']._serialized_options = b'\272H\003\310\001\001'
  _globals['_MIGRATEFSAREQUEST'].fields_by_name['batch_size']._loaded_options = None
  _globals['_MIGRATEFSAREQUEST'].fields_by_name['batch_size']._serialized_options = b'\272H\003\310\001\001'
  _globals['_MIGRATIONSERVICE'].methods_by_name['MigrateFSAData']._loaded_options = None
  _globals['_MIGRATIONSERVICE'].methods_by_name['MigrateFSAData']._serialized_options = b'\202\265\030\002\030\001\372\322\344\223\002\t\022\007PREVIEW\202\323\344\223\002\026\"\024/migrations/fsa-data'
  _globals['_FSADATATYPE']._serialized_start=960
  _globals['_FSADATATYPE']._serialized_end=1096
  _globals['_MIGRATIONSERVICERESPONSE']._serialized_start=302
  _globals['_MIGRATIONSERVICERESPONSE']._serialized_end=428
  _globals['_MIGRATIONSAMLREQUEST']._serialized_start=430
  _globals['_MIGRATIONSAMLREQUEST']._serialized_end=532
  _globals['_MIGRATEFSAREQUEST']._serialized_start=535
  _globals['_MIGRATEFSAREQUEST']._serialized_end=708
  _globals['_MIGRATIONFSARESPONSE']._serialized_start=710
  _globals['_MIGRATIONFSARESPONSE']._serialized_end=832
  _globals['_MIGRATIONSAMLRESPONSE']._serialized_start=834
  _globals['_MIGRATIONSAMLRESPONSE']._serialized_end=957
  _globals['_MIGRATIONSERVICE']._serialized_start=1099
  _globals['_MIGRATIONSERVICE']._serialized_end=1276
# @@protoc_insertion_point(module_scope)



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from scalekit.v1.commons import commons_pb2 as _commons_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from scalekit.v1.users import users_pb2 as _users_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MemberRole(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    MEMBER_ROLE_UNSPECIFIED: _ClassVar[MemberRole]
    ADMIN: _ClassVar[MemberRole]
    USER: _ClassVar[MemberRole]
MEMBER_ROLE_UNSPECIFIED: MemberRole
ADMIN: MemberRole
USER: MemberRole

class Member(_message.Message):
    __slots__ = ("id", "create_time", "update_time", "workspace_id", "role", "first_name", "last_name", "email", "metadata", "organizations", "user_profile", "external_id")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATIONS_FIELD_NUMBER: _ClassVar[int]
    USER_PROFILE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    workspace_id: str
    role: MemberRole
    first_name: str
    last_name: str
    email: str
    metadata: _containers.ScalarMap[str, str]
    organizations: _containers.RepeatedCompositeFieldContainer[_commons_pb2.OrganizationMembership]
    user_profile: _commons_pb2.UserProfile
    external_id: str
    def __init__(self, id: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., workspace_id: _Optional[str] = ..., role: _Optional[_Union[MemberRole, str]] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., email: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., organizations: _Optional[_Iterable[_Union[_commons_pb2.OrganizationMembership, _Mapping]]] = ..., user_profile: _Optional[_Union[_commons_pb2.UserProfile, _Mapping]] = ..., external_id: _Optional[str] = ...) -> None: ...

class CreateMemberRequest(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: Member
    def __init__(self, member: _Optional[_Union[Member, _Mapping]] = ...) -> None: ...

class CreateMemberResponse(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: Member
    def __init__(self, member: _Optional[_Union[Member, _Mapping]] = ...) -> None: ...

class UpdateMember(_message.Message):
    __slots__ = ("role", "first_name", "last_name", "metadata", "user_profile")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ROLE_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    USER_PROFILE_FIELD_NUMBER: _ClassVar[int]
    role: MemberRole
    first_name: str
    last_name: str
    metadata: _containers.ScalarMap[str, str]
    user_profile: _users_pb2.UpdateUserProfile
    def __init__(self, role: _Optional[_Union[MemberRole, str]] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., user_profile: _Optional[_Union[_users_pb2.UpdateUserProfile, _Mapping]] = ...) -> None: ...

class UpdateCurrentMemberRequest(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: UpdateMember
    def __init__(self, member: _Optional[_Union[UpdateMember, _Mapping]] = ...) -> None: ...

class UpdateMemberRequest(_message.Message):
    __slots__ = ("id", "member")
    ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    id: str
    member: UpdateMember
    def __init__(self, id: _Optional[str] = ..., member: _Optional[_Union[UpdateMember, _Mapping]] = ...) -> None: ...

class UpdateMemberResponse(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: Member
    def __init__(self, member: _Optional[_Union[Member, _Mapping]] = ...) -> None: ...

class GetCurrentMemberRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetMemberRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetMemberResponse(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: Member
    def __init__(self, member: _Optional[_Union[Member, _Mapping]] = ...) -> None: ...

class ListMemberRequest(_message.Message):
    __slots__ = ("page_size", "page_token")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListMemberResponse(_message.Message):
    __slots__ = ("next_page_token", "total_size", "members")
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    MEMBERS_FIELD_NUMBER: _ClassVar[int]
    next_page_token: str
    total_size: int
    members: _containers.RepeatedCompositeFieldContainer[Member]
    def __init__(self, next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ..., members: _Optional[_Iterable[_Union[Member, _Mapping]]] = ...) -> None: ...

class DeleteMemberRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SessionDetailsRequest(_message.Message):
    __slots__ = ("session_id",)
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    def __init__(self, session_id: _Optional[str] = ...) -> None: ...

class UserSessionDetailsRequest(_message.Message):
    __slots__ = ("user_id",)
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class RevokeSessionRequest(_message.Message):
    __slots__ = ("session_id",)
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    def __init__(self, session_id: _Optional[str] = ...) -> None: ...

class RevokeSessionResponse(_message.Message):
    __slots__ = ("revoked_session",)
    REVOKED_SESSION_FIELD_NUMBER: _ClassVar[int]
    revoked_session: SessionDetails
    def __init__(self, revoked_session: _Optional[_Union[SessionDetails, _Mapping]] = ...) -> None: ...

class UserSessionDetails(_message.Message):
    __slots__ = ("sessions",)
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    sessions: _containers.RepeatedCompositeFieldContainer[SessionDetails]
    def __init__(self, sessions: _Optional[_Iterable[_Union[SessionDetails, _Mapping]]] = ...) -> None: ...

class SessionDetails(_message.Message):
    __slots__ = ("session_id", "user_id", "authenticated_organizations", "organization_id", "created_at", "updated_at", "idle_expires_at", "absolute_expires_at", "expired_at", "logout_at", "status", "initial_user_agent", "initial_os", "initial_os_version", "initial_browser", "initial_browser_version", "initial_device_type", "initial_timezone", "initial_ip", "initial_location", "latest_user_agent", "latest_os", "latest_os_version", "latest_browser", "latest_browser_version", "latest_device_type", "latest_timezone", "latest_ip", "latest_location")
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATED_ORGANIZATIONS_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    IDLE_EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    ABSOLUTE_EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRED_AT_FIELD_NUMBER: _ClassVar[int]
    LOGOUT_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    INITIAL_USER_AGENT_FIELD_NUMBER: _ClassVar[int]
    INITIAL_OS_FIELD_NUMBER: _ClassVar[int]
    INITIAL_OS_VERSION_FIELD_NUMBER: _ClassVar[int]
    INITIAL_BROWSER_FIELD_NUMBER: _ClassVar[int]
    INITIAL_BROWSER_VERSION_FIELD_NUMBER: _ClassVar[int]
    INITIAL_DEVICE_TYPE_FIELD_NUMBER: _ClassVar[int]
    INITIAL_TIMEZONE_FIELD_NUMBER: _ClassVar[int]
    INITIAL_IP_FIELD_NUMBER: _ClassVar[int]
    INITIAL_LOCATION_FIELD_NUMBER: _ClassVar[int]
    LATEST_USER_AGENT_FIELD_NUMBER: _ClassVar[int]
    LATEST_OS_FIELD_NUMBER: _ClassVar[int]
    LATEST_OS_VERSION_FIELD_NUMBER: _ClassVar[int]
    LATEST_BROWSER_FIELD_NUMBER: _ClassVar[int]
    LATEST_BROWSER_VERSION_FIELD_NUMBER: _ClassVar[int]
    LATEST_DEVICE_TYPE_FIELD_NUMBER: _ClassVar[int]
    LATEST_TIMEZONE_FIELD_NUMBER: _ClassVar[int]
    LATEST_IP_FIELD_NUMBER: _ClassVar[int]
    LATEST_LOCATION_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    user_id: str
    authenticated_organizations: _containers.RepeatedScalarFieldContainer[str]
    organization_id: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    idle_expires_at: _timestamp_pb2.Timestamp
    absolute_expires_at: _timestamp_pb2.Timestamp
    expired_at: _timestamp_pb2.Timestamp
    logout_at: _timestamp_pb2.Timestamp
    status: str
    initial_user_agent: str
    initial_os: str
    initial_os_version: str
    initial_browser: str
    initial_browser_version: str
    initial_device_type: str
    initial_timezone: str
    initial_ip: str
    initial_location: Location
    latest_user_agent: str
    latest_os: str
    latest_os_version: str
    latest_browser: str
    latest_browser_version: str
    latest_device_type: str
    latest_timezone: str
    latest_ip: str
    latest_location: Location
    def __init__(self, session_id: _Optional[str] = ..., user_id: _Optional[str] = ..., authenticated_organizations: _Optional[_Iterable[str]] = ..., organization_id: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., idle_expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., absolute_expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., expired_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., logout_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., status: _Optional[str] = ..., initial_user_agent: _Optional[str] = ..., initial_os: _Optional[str] = ..., initial_os_version: _Optional[str] = ..., initial_browser: _Optional[str] = ..., initial_browser_version: _Optional[str] = ..., initial_device_type: _Optional[str] = ..., initial_timezone: _Optional[str] = ..., initial_ip: _Optional[str] = ..., initial_location: _Optional[_Union[Location, _Mapping]] = ..., latest_user_agent: _Optional[str] = ..., latest_os: _Optional[str] = ..., latest_os_version: _Optional[str] = ..., latest_browser: _Optional[str] = ..., latest_browser_version: _Optional[str] = ..., latest_device_type: _Optional[str] = ..., latest_timezone: _Optional[str] = ..., latest_ip: _Optional[str] = ..., latest_location: _Optional[_Union[Location, _Mapping]] = ...) -> None: ...

class Location(_message.Message):
    __slots__ = ("region", "region_subdivision", "city", "latitude", "longitude")
    REGION_FIELD_NUMBER: _ClassVar[int]
    REGION_SUBDIVISION_FIELD_NUMBER: _ClassVar[int]
    CITY_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    region: str
    region_subdivision: str
    city: str
    latitude: str
    longitude: str
    def __init__(self, region: _Optional[str] = ..., region_subdivision: _Optional[str] = ..., city: _Optional[str] = ..., latitude: _Optional[str] = ..., longitude: _Optional[str] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateMcpRequest(_message.Message):
    __slots__ = ("mcp",)
    MCP_FIELD_NUMBER: _ClassVar[int]
    mcp: Mcp
    def __init__(self, mcp: _Optional[_Union[Mcp, _Mapping]] = ...) -> None: ...

class CreateMcpResponse(_message.Message):
    __slots__ = ("mcp",)
    MCP_FIELD_NUMBER: _ClassVar[int]
    mcp: Mcp
    def __init__(self, mcp: _Optional[_Union[Mcp, _Mapping]] = ...) -> None: ...

class Mcp(_message.Message):
    __slots__ = ("id", "tool_mappings", "connected_account_identifier", "url")
    ID_FIELD_NUMBER: _ClassVar[int]
    TOOL_MAPPINGS_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_ACCOUNT_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    id: str
    tool_mappings: _containers.RepeatedCompositeFieldContainer[ToolMapping]
    connected_account_identifier: str
    url: str
    def __init__(self, id: _Optional[str] = ..., tool_mappings: _Optional[_Iterable[_Union[ToolMapping, _Mapping]]] = ..., connected_account_identifier: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...

class ToolMapping(_message.Message):
    __slots__ = ("tool_names", "connection_name", "status")
    TOOL_NAMES_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    tool_names: _containers.RepeatedScalarFieldContainer[str]
    connection_name: str
    status: str
    def __init__(self, tool_names: _Optional[_Iterable[str]] = ..., connection_name: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class GetMcpRequest(_message.Message):
    __slots__ = ("mcp_id",)
    MCP_ID_FIELD_NUMBER: _ClassVar[int]
    mcp_id: str
    def __init__(self, mcp_id: _Optional[str] = ...) -> None: ...

class GetMcpResponse(_message.Message):
    __slots__ = ("mcp",)
    MCP_FIELD_NUMBER: _ClassVar[int]
    mcp: Mcp
    def __init__(self, mcp: _Optional[_Union[Mcp, _Mapping]] = ...) -> None: ...

class ListMcpRequest(_message.Message):
    __slots__ = ("filter",)
    class Filter(_message.Message):
        __slots__ = ("connected_account_identifier", "link_token")
        CONNECTED_ACCOUNT_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
        LINK_TOKEN_FIELD_NUMBER: _ClassVar[int]
        connected_account_identifier: str
        link_token: str
        def __init__(self, connected_account_identifier: _Optional[str] = ..., link_token: _Optional[str] = ...) -> None: ...
    FILTER_FIELD_NUMBER: _ClassVar[int]
    filter: ListMcpRequest.Filter
    def __init__(self, filter: _Optional[_Union[ListMcpRequest.Filter, _Mapping]] = ...) -> None: ...

class ListMcpResponse(_message.Message):
    __slots__ = ("mcps",)
    MCPS_FIELD_NUMBER: _ClassVar[int]
    mcps: _containers.RepeatedCompositeFieldContainer[Mcp]
    def __init__(self, mcps: _Optional[_Iterable[_Union[Mcp, _Mapping]]] = ...) -> None: ...

class DeleteMcpRequest(_message.Message):
    __slots__ = ("mcp_id",)
    MCP_ID_FIELD_NUMBER: _ClassVar[int]
    mcp_id: str
    def __init__(self, mcp_id: _Optional[str] = ...) -> None: ...

class DeleteMcpResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Constraint(_message.Message):
    __slots__ = ("id", "message", "expression")
    ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    id: str
    message: str
    expression: str
    def __init__(self, id: _Optional[str] = ..., message: _Optional[str] = ..., expression: _Optional[str] = ...) -> None: ...

class Violations(_message.Message):
    __slots__ = ("violations",)
    VIOLATIONS_FIELD_NUMBER: _ClassVar[int]
    violations: _containers.RepeatedCompositeFieldContainer[Violation]
    def __init__(self, violations: _Optional[_Iterable[_Union[Violation, _Mapping]]] = ...) -> None: ...

class Violation(_message.Message):
    __slots__ = ("field_path", "constraint_id", "message", "for_key")
    FIELD_PATH_FIELD_NUMBER: _ClassVar[int]
    CONSTRAINT_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    FOR_KEY_FIELD_NUMBER: _ClassVar[int]
    field_path: str
    constraint_id: str
    message: str
    for_key: bool
    def __init__(self, field_path: _Optional[str] = ..., constraint_id: _Optional[str] = ..., message: _Optional[str] = ..., for_key: bool = ...) -> None: ...




from faker import Faker
from basetest import BaseTest

from scalekit.v1.organizations.organizations_pb2 import CreateOrganization
from scalekit.v1.directories.directories_pb2 import CreateDirectory
from scalekit.v1.directories.directories_pb2 import DirectoryProvider, DirectoryType


class TestDirectory(BaseTest):
    """ Class definition for Test Directory Class """

    def setUp(self):
        """ """
        self.org_id = None
        self.dir_id = None

    def test_create_directory(self):
        """ Method to test create directory """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        directory = CreateDirectory(directory_provider=DirectoryProvider.OKTA, directory_type=DirectoryType.SCIM)
        response = self.scalekit_client.directory.create_directory(organization_id=self.org_id, directory=directory)
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertEqual(response[0].directory.directory_provider, DirectoryProvider.OKTA)
        self.assertEqual(response[0].directory.directory_type, DirectoryType.SCIM)
        self.assertEqual(response[0].directory.organization_id, self.org_id)
        self.assertTrue(response[0].directory.enabled)
        self.dir_id = response[0].directory.id

    def test_get_directory(self):
        """ Method to test get directory """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        directory = CreateDirectory(directory_provider=DirectoryProvider.OKTA, directory_type=DirectoryType.SCIM)
        create_response = self.scalekit_client.directory.create_directory(organization_id=self.org_id, directory=directory)
        self.dir_id = create_response[0].directory.id

        response = self.scalekit_client.directory.get_directory(organization_id=self.org_id, directory_id=self.dir_id)
        self.assertEqual(response[1].code().name, "OK")
        self.assertEqual(response[0].directory.id, self.dir_id)

    def test_list_directories(self):
        """ Method to test list directories """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        directory = CreateDirectory(directory_provider=DirectoryProvider.OKTA, directory_type=DirectoryType.SCIM)
        create_response = self.scalekit_client.directory.create_directory(organization_id=self.org_id, directory=directory)
        self.dir_id = create_response[0].directory.id

        response = self.scalekit_client.directory.list_directories(organization_id=self.org_id)
        self.assertEqual(response[1].code().name, "OK")
        self.assertTrue(response[0] is not None)
        self.assertTrue(len(response[0].directories) > 0)
        self.assertEqual(response[0].directories[0].id, self.dir_id)
        self.assertEqual(response[0].directories[0].directory_provider, DirectoryProvider.OKTA)
        self.assertEqual(response[0].directories[0].directory_type, DirectoryType.SCIM)
        self.assertEqual(response[0].directories[0].organization_id, self.org_id)

    def test_disable_enable_directory(self):
        """ Method to test enable directory """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        directory = CreateDirectory(directory_provider=DirectoryProvider.OKTA, directory_type=DirectoryType.SCIM)
        create_response = self.scalekit_client.directory.create_directory(
            organization_id=self.org_id, directory=directory)
        self.dir_id = create_response[0].directory.id

        disable_response = self.scalekit_client.directory.disable_directory(organization_id=self.org_id, directory_id=self.dir_id)
        self.assertEqual(disable_response[1].code().name, "OK")

        get_disabled_dir = self.scalekit_client.directory.get_directory(organization_id=self.org_id, directory_id=self.dir_id)
        self.assertFalse(get_disabled_dir[0].directory.enabled)

        enable_response = self.scalekit_client.directory.enable_directory(organization_id=self.org_id, directory_id=self.dir_id)
        self.assertEqual(enable_response[1].code().name, "OK")

        get_enabled_dir = self.scalekit_client.directory.get_directory(organization_id=self.org_id, directory_id=self.dir_id)
        self.assertTrue(get_enabled_dir[0].directory.enabled)

    def test_delete_directory(self):
        """ Method to test delete directory """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        directory = CreateDirectory(directory_provider=DirectoryProvider.OKTA, directory_type=DirectoryType.SCIM)
        create_response = self.scalekit_client.directory.create_directory(organization_id=self.org_id, directory=directory)
        self.dir_id = create_response[0].directory.id

        disable_response = self.scalekit_client.directory.disable_directory(organization_id=self.org_id, directory_id=self.dir_id)
        self.assertEqual(disable_response[1].code().name, "OK")

        response = self.scalekit_client.directory.delete_directory(organization_id=self.org_id, directory_id=self.dir_id)
        self.assertEqual(response[1].code().name, "OK")

        try:
            self.scalekit_client.directory.get_directory(organization_id=self.org_id, directory_id=self.dir_id)
        except Exception as e:
            self.assertEqual(e.args[0], "directory not found")
            self.dir_id = None

    def test_get_primary_directory_by_organization_id(self):
        """ Method to test get primary directory by organization id """
        organization = CreateOrganization(display_name=Faker().company(), external_id=Faker().uuid4())
        org_response = self.scalekit_client.organization.create_organization(organization=organization)
        self.org_id = org_response[0].organization.id

        directory = CreateDirectory(directory_provider=DirectoryProvider.OKTA, directory_type=DirectoryType.SCIM)
        create_response = self.scalekit_client.directory.create_directory(organization_id=self.org_id, directory=directory)
        self.dir_id = create_response[0].directory.id

        response = self.scalekit_client.directory.get_primary_directory_by_organization_id(organization_id=self.org_id)
        self.assertEqual(response.id, self.dir_id)
        self.assertEqual(response.organization_id, self.org_id)

    def tearDown(self):
        """ Method to clean up """
        if self.dir_id:
            self.scalekit_client.directory.disable_directory(organization_id=self.org_id, directory_id=self.dir_id)
            self.scalekit_client.directory.delete_directory(organization_id=self.org_id, directory_id=self.dir_id)
        if self.org_id:
            self.scalekit_client.organization.delete_organization(organization_id=self.org_id)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/domains/domains.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from scalekit.v1.options import options_pb2 as scalekit_dot_v1_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!scalekit/v1/domains/domains.proto\x12\x13scalekit.v1.domains\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a!scalekit/v1/options/options.proto\"\xfe\x01\n\x13\x43reateDomainRequest\x12\x34\n\x0forganization_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\x0eorganizationId\x12,\n\x0b\x65xternal_id\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\nexternalId\x12(\n\rconnection_id\x18\x03 \x01(\tH\x01R\x0c\x63onnectionId\x88\x01\x01\x12\x39\n\x06\x64omain\x18\x04 \x01(\x0b\x32!.scalekit.v1.domains.CreateDomainR\x06\x64omainB\x0c\n\nidentitiesB\x10\n\x0e_connection_id\"K\n\x14\x43reateDomainResponse\x12\x33\n\x06\x64omain\x18\x01 \x01(\x0b\x32\x1b.scalekit.v1.domains.DomainR\x06\x64omain\"w\n\x0c\x43reateDomain\x12%\n\x06\x64omain\x18\x01 \x01(\tB\r\xbaH\nr\x05\x10\x04\x18\xff\x01\xc8\x01\x01R\x06\x64omain\x12@\n\x0b\x64omain_type\x18\x02 \x01(\x0e\x32\x1f.scalekit.v1.domains.DomainTypeR\ndomainType\"\x8e\x02\n\x13UpdateDomainRequest\x12\x34\n\x0forganization_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\x0eorganizationId\x12,\n\x0b\x65xternal_id\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\nexternalId\x12(\n\rconnection_id\x18\x03 \x01(\tH\x01R\x0c\x63onnectionId\x88\x01\x01\x12\x0e\n\x02id\x18\x04 \x01(\tR\x02id\x12\x39\n\x06\x64omain\x18\x05 \x01(\x0b\x32!.scalekit.v1.domains.UpdateDomainR\x06\x64omainB\x0c\n\nidentitiesB\x10\n\x0e_connection_id\"\x0e\n\x0cUpdateDomain\"K\n\x14UpdateDomainResponse\x12\x33\n\x06\x64omain\x18\x01 \x01(\x0b\x32\x1b.scalekit.v1.domains.DomainR\x06\x64omain\"\x94\x01\n\x10GetDomainRequest\x12\x34\n\x0forganization_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\x0eorganizationId\x12,\n\x0b\x65xternal_id\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\nexternalId\x12\x0e\n\x02id\x18\x03 \x01(\tR\x02idB\x0c\n\nidentities\"H\n\x11GetDomainResponse\x12\x33\n\x06\x64omain\x18\x01 \x01(\x0b\x32\x1b.scalekit.v1.domains.DomainR\x06\x64omain\"\xd3\x01\n\x13\x44\x65leteDomainRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x34\n\x0forganization_id\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\x0eorganizationId\x12,\n\x0b\x65xternal_id\x18\x03 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\nexternalId\x12(\n\rconnection_id\x18\x04 \x01(\tH\x01R\x0c\x63onnectionId\x88\x01\x01\x42\x0c\n\nidentitiesB\x10\n\x0e_connection_id\"\xa6\x03\n\x11ListDomainRequest\x12\x34\n\x0forganization_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\x0eorganizationId\x12,\n\x0b\x65xternal_id\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\nexternalId\x12(\n\rconnection_id\x18\x03 \x01(\tH\x01R\x0c\x63onnectionId\x88\x01\x01\x12\x1d\n\x07include\x18\x04 \x01(\tH\x02R\x07include\x88\x01\x01\x12\x38\n\tpage_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x08pageSize\x12<\n\x0bpage_number\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\npageNumber\x12@\n\x0b\x64omain_type\x18\x07 \x01(\x0e\x32\x1f.scalekit.v1.domains.DomainTypeR\ndomainTypeB\x0c\n\nidentitiesB\x10\n\x0e_connection_idB\n\n\x08_include\"\xa7\x01\n\x13VerifyDomainRequest\x12\x34\n\x0forganization_id\x18\x01 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\x0eorganizationId\x12,\n\x0b\x65xternal_id\x18\x02 \x01(\tB\t\xbaH\x06r\x04\x10\x01\x18 H\x00R\nexternalId\x12\x1e\n\x02id\x18\x04 \x01(\tB\x0e\xbaH\x0br\t\x10\x01\x18 :\x03\x64omR\x02idB\x0c\n\nidentities\"\x89\x01\n\x12ListDomainResponse\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\x1f\n\x0bpage_number\x18\x02 \x01(\x05R\npageNumber\x12\x35\n\x07\x64omains\x18\x03 \x03(\x0b\x32\x1b.scalekit.v1.domains.DomainR\x07\x64omains\"5\n\x1bListAuthorizedDomainRequest\x12\x16\n\x06origin\x18\x01 \x01(\tR\x06origin\"8\n\x1cListAuthorizedDomainResponse\x12\x18\n\x07\x64omains\x18\x01 \x03(\tR\x07\x64omains\"\xc0\x04\n\x06\x44omain\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12%\n\x0e\x65nvironment_id\x18\x03 \x01(\tR\renvironmentId\x12\'\n\x0forganization_id\x18\x04 \x01(\tR\x0eorganizationId\x12#\n\rconnection_id\x18\x05 \x01(\tR\x0c\x63onnectionId\x12$\n\x0etxt_record_key\x18\x06 \x01(\tR\x0ctxtRecordKey\x12*\n\x11txt_record_secret\x18\x07 \x01(\tR\x0ftxtRecordSecret\x12X\n\x13verification_status\x18\x08 \x01(\x0e\x32\'.scalekit.v1.domains.VerificationStatusR\x12verificationStatus\x12;\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12;\n\x0bupdate_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x12\"\n\ncreated_by\x18\x0b \x01(\tH\x00R\tcreatedBy\x88\x01\x01\x12@\n\x0b\x64omain_type\x18\x0c \x01(\x0e\x32\x1f.scalekit.v1.domains.DomainTypeR\ndomainTypeB\r\n\x0b_created_by*s\n\x12VerificationStatus\x12#\n\x1fVERIFICATION_STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08VERIFIED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x11\n\rAUTO_VERIFIED\x10\x04*\\\n\nDomainType\x12\x1b\n\x17\x44OMAIN_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x41LLOWED_EMAIL_DOMAIN\x10\x01\x12\x17\n\x13ORGANIZATION_DOMAIN\x10\x02\x32\x87\x0b\n\rDomainService\x12\xd5\x01\n\x0c\x43reateDomain\x12(.scalekit.v1.domains.CreateDomainRequest\x1a).scalekit.v1.domains.CreateDomainResponse\"p\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02\x64\"//api/v1/organizations/{organization_id}/domains:\x06\x64omainZ)\"\x1f/api/v1/organizations/-/domains:\x06\x64omain\x12\xda\x01\n\x0cUpdateDomain\x12(.scalekit.v1.domains.UpdateDomainRequest\x1a).scalekit.v1.domains.UpdateDomainResponse\"u\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02i24/api/v1/organizations/{organization_id}/domains/{id}:\x06\x64omainZ)2\x1f/api/v1/organizations/-/domains:\x06\x64omain\x12\xce\x01\n\x0cVerifyDomain\x12(.scalekit.v1.domains.VerifyDomainRequest\x1a\x1a.google.protobuf.BoolValue\"x\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02l2;/api/v1/organizations/{organization_id}/domains/{id}:verifyZ-2+/api/v1/organizations/-/domains/{id}:verify\x12\xc6\x01\n\tGetDomain\x12%.scalekit.v1.domains.GetDomainRequest\x1a&.scalekit.v1.domains.GetDomainResponse\"j\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02^\x12\x34/api/v1/organizations/{organization_id}/domains/{id}Z&\x12$/api/v1/organizations/-/domains/{id}\x12\xbc\x01\n\x0c\x44\x65leteDomain\x12(.scalekit.v1.domains.DeleteDomainRequest\x1a\x16.google.protobuf.Empty\"j\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02^*4/api/v1/organizations/{organization_id}/domains/{id}Z&*$/api/v1/organizations/-/domains/{id}\x12\xc0\x01\n\x0bListDomains\x12&.scalekit.v1.domains.ListDomainRequest\x1a\'.scalekit.v1.domains.ListDomainResponse\"`\x82\xb5\x18\x02\x18t\x82\xd3\xe4\x93\x02T\x12//api/v1/organizations/{organization_id}/domainsZ!\x12\x1f/api/v1/organizations/-/domains\x12\xa4\x01\n\x15ListAuthorizedDomains\x12\x30.scalekit.v1.domains.ListAuthorizedDomainRequest\x1a\x31.scalekit.v1.domains.ListAuthorizedDomainResponse\"&\x82\xb5\x18\x02\x18\x01\x82\xd3\xe4\x93\x02\x1a\x12\x18/api/v1/domains/{origin}B3Z1github.com/scalekit-inc/scalekit/pkg/grpc/domainsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.domains.domains_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/scalekit-inc/scalekit/pkg/grpc/domains'
  _globals['_CREATEDOMAINREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATEDOMAINREQUEST'].fields_by_name['organization_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_CREATEDOMAINREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_CREATEDOMAINREQUEST'].fields_by_name['external_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_CREATEDOMAIN'].fields_by_name['domain']._loaded_options = None
  _globals['_CREATEDOMAIN'].fields_by_name['domain']._serialized_options = b'\272H\nr\005\020\004\030\377\001\310\001\001'
  _globals['_UPDATEDOMAINREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_UPDATEDOMAINREQUEST'].fields_by_name['organization_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_UPDATEDOMAINREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_UPDATEDOMAINREQUEST'].fields_by_name['external_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_GETDOMAINREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_GETDOMAINREQUEST'].fields_by_name['organization_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_GETDOMAINREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_GETDOMAINREQUEST'].fields_by_name['external_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_DELETEDOMAINREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_DELETEDOMAINREQUEST'].fields_by_name['organization_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_DELETEDOMAINREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_DELETEDOMAINREQUEST'].fields_by_name['external_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_LISTDOMAINREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTDOMAINREQUEST'].fields_by_name['organization_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_LISTDOMAINREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_LISTDOMAINREQUEST'].fields_by_name['external_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_VERIFYDOMAINREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_VERIFYDOMAINREQUEST'].fields_by_name['organization_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_VERIFYDOMAINREQUEST'].fields_by_name['external_id']._loaded_options = None
  _globals['_VERIFYDOMAINREQUEST'].fields_by_name['external_id']._serialized_options = b'\272H\006r\004\020\001\030 '
  _globals['_VERIFYDOMAINREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_VERIFYDOMAINREQUEST'].fields_by_name['id']._serialized_options = b'\272H\013r\t\020\001\030 :\003dom'
  _globals['_DOMAINSERVICE'].methods_by_name['CreateDomain']._loaded_options = None
  _globals['_DOMAINSERVICE'].methods_by_name['CreateDomain']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002d\"//api/v1/organizations/{organization_id}/domains:\006domainZ)\"\037/api/v1/organizations/-/domains:\006domain'
  _globals['_DOMAINSERVICE'].methods_by_name['UpdateDomain']._loaded_options = None
  _globals['_DOMAINSERVICE'].methods_by_name['UpdateDomain']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002i24/api/v1/organizations/{organization_id}/domains/{id}:\006domainZ)2\037/api/v1/organizations/-/domains:\006domain'
  _globals['_DOMAINSERVICE'].methods_by_name['VerifyDomain']._loaded_options = None
  _globals['_DOMAINSERVICE'].methods_by_name['VerifyDomain']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002l2;/api/v1/organizations/{organization_id}/domains/{id}:verifyZ-2+/api/v1/organizations/-/domains/{id}:verify'
  _globals['_DOMAINSERVICE'].methods_by_name['GetDomain']._loaded_options = None
  _globals['_DOMAINSERVICE'].methods_by_name['GetDomain']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002^\0224/api/v1/organizations/{organization_id}/domains/{id}Z&\022$/api/v1/organizations/-/domains/{id}'
  _globals['_DOMAINSERVICE'].methods_by_name['DeleteDomain']._loaded_options = None
  _globals['_DOMAINSERVICE'].methods_by_name['DeleteDomain']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002^*4/api/v1/organizations/{organization_id}/domains/{id}Z&*$/api/v1/organizations/-/domains/{id}'
  _globals['_DOMAINSERVICE'].methods_by_name['ListDomains']._loaded_options = None
  _globals['_DOMAINSERVICE'].methods_by_name['ListDomains']._serialized_options = b'\202\265\030\002\030t\202\323\344\223\002T\022//api/v1/organizations/{organization_id}/domainsZ!\022\037/api/v1/organizations/-/domains'
  _globals['_DOMAINSERVICE'].methods_by_name['ListAuthorizedDomains']._loaded_options = None
  _globals['_DOMAINSERVICE'].methods_by_name['ListAuthorizedDomains']._serialized_options = b'\202\265\030\002\030\001\202\323\344\223\002\032\022\030/api/v1/domains/{origin}'
  _globals['_VERIFICATIONSTATUS']._serialized_start=2966
  _globals['_VERIFICATIONSTATUS']._serialized_end=3081
  _globals['_DOMAINTYPE']._serialized_start=3083
  _globals['_DOMAINTYPE']._serialized_end=3175
  _globals['_CREATEDOMAINREQUEST']._serialized_start=280
  _globals['_CREATEDOMAINREQUEST']._serialized_end=534
  _globals['_CREATEDOMAINRESPONSE']._serialized_start=536
  _globals['_CREATEDOMAINRESPONSE']._serialized_end=611
  _globals['_CREATEDOMAIN']._serialized_start=613
  _globals['_CREATEDOMAIN']._serialized_end=732
  _globals['_UPDATEDOMAINREQUEST']._serialized_start=735
  _globals['_UPDATEDOMAINREQUEST']._serialized_end=1005
  _globals['_UPDATEDOMAIN']._serialized_start=1007
  _globals['_UPDATEDOMAIN']._serialized_end=1021
  _globals['_UPDATEDOMAINRESPONSE']._serialized_start=1023
  _globals['_UPDATEDOMAINRESPONSE']._serialized_end=1098
  _globals['_GETDOMAINREQUEST']._serialized_start=1101
  _globals['_GETDOMAINREQUEST']._serialized_end=1249
  _globals['_GETDOMAINRESPONSE']._serialized_start=1251
  _globals['_GETDOMAINRESPONSE']._serialized_end=1323
  _globals['_DELETEDOMAINREQUEST']._serialized_start=1326
  _globals['_DELETEDOMAINREQUEST']._serialized_end=1537
  _globals['_LISTDOMAINREQUEST']._serialized_start=1540
  _globals['_LISTDOMAINREQUEST']._serialized_end=1962
  _globals['_VERIFYDOMAINREQUEST']._serialized_start=1965
  _globals['_VERIFYDOMAINREQUEST']._serialized_end=2132
  _globals['_LISTDOMAINRESPONSE']._serialized_start=2135
  _globals['_LISTDOMAINRESPONSE']._serialized_end=2272
  _globals['_LISTAUTHORIZEDDOMAINREQUEST']._serialized_start=2274
  _globals['_LISTAUTHORIZEDDOMAINREQUEST']._serialized_end=2327
  _globals['_LISTAUTHORIZEDDOMAINRESPONSE']._serialized_start=2329
  _globals['_LISTAUTHORIZEDDOMAINRESPONSE']._serialized_end=2385
  _globals['_DOMAIN']._serialized_start=2388
  _globals['_DOMAIN']._serialized_end=2964
  _globals['_DOMAINSERVICE']._serialized_start=3178
  _globals['_DOMAINSERVICE']._serialized_end=4593
# @@protoc_insertion_point(module_scope)
